@@ -3,17 +3,18 @@ module Sound.OSC.Transport.FD.TCP where
 
 import qualified Data.ByteString.Lazy as B {- bytestring -}
 import Control.Monad {- base -}
-import Network {- network -}
+import qualified Network as N {- network -}
 import System.IO {- base -}
 
-import Sound.OSC.Class
-import Sound.OSC.Coding
-import Sound.OSC.Coding.Byte
-import Sound.OSC.Transport.FD
+import Sound.OSC.Coding.Class {- hosc -}
+import Sound.OSC.Coding.Byte {- hosc -}
+import Sound.OSC.Transport.FD {- hosc -}
+import Sound.OSC.Packet.Class {- hosc -}
 
 -- | The TCP transport handle data type.
 data TCP = TCP {tcpHandle :: Handle}
 
+-- | 'TCP' is an instance of 'Transport'.
 instance Transport TCP where
    sendOSC (TCP fd) msg =
       do let b = encodeOSC msg
@@ -26,18 +27,28 @@ instance Transport TCP where
          return (decodePacket b1)
    close (TCP fd) = hClose fd
 
--- | Make a 'TCP' connection.
+{- | Make a 'TCP' connection.
+
+> import Sound.OSC.Core
+> import Sound.OSC.Transport.FD
+> import Sound.OSC.Transport.FD.TCP
+> let t = openTCP "127.0.0.1" 57110
+> let m1 = message "/dumpOSC" [Int32 1]
+> let m2 = message "/g_new" [Int32 1]
+> withTransport t (\fd -> let f = sendMessage fd in f m1 >> f m2)
+
+-}
 openTCP :: String -> Int -> IO TCP
 openTCP host =
     liftM TCP .
-    connectTo host .
-    PortNumber .
+    N.connectTo host .
+    N.PortNumber .
     fromIntegral
 
 -- | A trivial 'TCP' /OSC/ server.
 tcpServer' :: Int -> (TCP -> IO ()) -> IO ()
 tcpServer' p f = do
-  s <- listenOn (PortNumber (fromIntegral p))
-  (sequence_ . repeat) (do (fd, _, _) <- accept s
+  s <- N.listenOn (N.PortNumber (fromIntegral p))
+  (sequence_ . repeat) (do (fd, _, _) <- N.accept s
                            f (TCP fd)
                            return ())
